.. py:currentmodule:: rubin_sim.data

.. _rubin_sim.data:

==============
rubin_sim data
==============

The rubin_sim.data module provides a utility to interpret the location of the RUBIN_SIM_DATA_DIR
and provide information on the current simulated baseline pointing history.


Python API
==========

* :ref:`rubin_sim.data api`

* :ref:`search`